# Autogenerated by Astropy's setup.py on 2019-02-24 01:08:39 UTC
from __future__ import unicode_literals
import datetime

version = "3.1.2"
githash = "072b1655d9985e3126c77fab7c1e3010f20659a2"


major = 3
minor = 1
bugfix = 2

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 2, 24, 1, 8, 39)
debug = False

astropy_helpers_version = "3.1"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
